<?php
/*
Plugin Name: EVE Rigeneratore di Cache
Description: Un plugin per rigenerare la cache del sito pingando gli URL.
Version: 1.0
Author: Giovanni Sacheli
*/

// Aggiungi una pagina di menu nel backend
add_action('admin_menu', 'aggiungi_pagina_rigenerazione_cache');
function aggiungi_pagina_rigenerazione_cache() {
    add_menu_page('Rigenera Cache', 'Rigenera Cache', 'manage_options', 'rigenera-cache', 'pagina_rigenerazione_cache_html', 'dashicons-update');
}

// Contenuto della pagina del plugin
function pagina_rigenerazione_cache_html() {
    ?>
    <div class="wrap">
        <h1>Rigenera Cache</h1>
        <button id="rigenera-cache">Rigenera Cache</button>
        <div id="risultato"></div>
    </div>
    <?php
}

// Aggiungi azioni AJAX per ottieni_urls
add_action('wp_ajax_ottieni_urls', 'ottieni_urls_handler');
function ottieni_urls_handler() {
    if (!current_user_can('manage_options')) {
        wp_die('Non autorizzato');
    }

    $args = array(
        'post_type' => 'any',
        'posts_per_page' => -1,
        'post_status' => 'publish',
    );

    $query = new WP_Query($args);
    $urls = [];

    if ($query->have_posts()) {
        while ($query->have_posts()) {
            $query->the_post();
            $urls[] = get_permalink();
        }
    }

    echo json_encode($urls);
    wp_die();
}

add_action('wp_ajax_pinga_url', 'pinga_url_handler');
function pinga_url_handler() {
    if (!current_user_can('manage_options')) {
        wp_die('Non autorizzato');
    }

    $url = isset($_POST['url']) ? esc_url_raw($_POST['url']) : '';

    if (!empty($url)) {
        wp_remote_get($url); // Effettua il ping dell'URL
        echo "Pingato: $url";
    } else {
        echo "URL non valido";
    }

    wp_die();
}

// Enqueue script JS per AJAX
add_action('admin_enqueue_scripts', 'enqueue_rigenera_cache_script');
function enqueue_rigenera_cache_script($hook) {
    // Assicurati che lo script sia aggiunto solo alla pagina del plugin
    if ('toplevel_page_rigenera-cache' !== $hook) {
        return;
    }
    wp_enqueue_script('rigenera-cache-script', plugin_dir_url(__FILE__) . 'rigenera-cache.js', array('jquery'), null, true);
    wp_localize_script('rigenera-cache-script', 'ajax_object', array('ajax_url' => admin_url('admin-ajax.php')));
}
